@@ -47,6 +47,7 @@ import supybot.irclib as irclib
 import supybot.ircmsgs as ircmsgs
 import supybot.ircutils as ircutils
 import supybot.callbacks as callbacks
+import supybot.registry as registry
 from supybot import commands
 
 from supybot.i18n import PluginInternationalization, internationalizeDocstring
@@ -76,6 +77,8 @@ class RegexpTimeout(Exception):
     pass
 
 class Misc(callbacks.Plugin):
+    """Miscellaneous commands to access Supybot core. This is a core Supybot
+    module that should not be removed!"""
     def __init__(self, irc):
         self.__parent = super(Misc, self)
         self.__parent.__init__(irc)
@@ -179,6 +182,10 @@ class Misc(callbacks.Plugin):
                 else:
                     pass # Let's just do nothing, I can't think of better.
 
+    def isPublic(self, cb):
+        name = cb.name()
+        return conf.supybot.plugins.get(name).public()
+
     @internationalizeDocstring
     def list(self, irc, msg, args, optlist, cb):
         """[--private] [--unloaded] [<plugin>]
@@ -202,7 +209,7 @@ class Misc(callbacks.Plugin):
                    not ircdb.checkCapability(msg.prefix, 'owner'):
                     irc.errorNoCapability('owner')
         if unloaded and private:
-            irc.error(_('--private and --unloaded are uncompatible options.'))
+            irc.error(_('--private and --unloaded are incompatible options.'))
             return
         if not cb:
             if unloaded:
@@ -222,12 +229,9 @@ class Misc(callbacks.Plugin):
                 plugins.sort()
                 irc.reply(format('%L', plugins))
             else:
-                def isPublic(cb):
-                    name = cb.name()
-                    return conf.supybot.plugins.get(name).public()
                 names = [cb.name() for cb in irc.callbacks
-                         if (private and not isPublic(cb)) or
-                            (not private and isPublic(cb))]
+                         if (private and not self.isPublic(cb)) or
+                            (not private and self.isPublic(cb))]
                 names.sort()
                 if names:
                     irc.reply(format('%L', names))
@@ -286,6 +290,13 @@ class Misc(callbacks.Plugin):
         You may also want to use the 'list' command to list all available
         plugins and commands.
         """
+        if not command:
+            cHelp = self.registryValue("customHelpString")
+            if cHelp:
+                irc.reply(cHelp)
+            else:
+                irc.error()
+            return
         command = list(map(callbacks.canonicalName, command))
         (maxL, cbs) = irc.findCallbacksForArgs(command)
         if maxL == command:
@@ -298,9 +309,16 @@ class Misc(callbacks.Plugin):
                 assert cbs, 'Odd, maxL == command, but no cbs.'
                 irc.reply(_.__call__(cbs[0].getCommandHelp(command, False)))
         else:
-            irc.error(format(_('There is no command %q.'),
-                             callbacks.formatCommand(command)))
-    help = wrap(help, [many('something')])
+            plugins = [cb.name() for cb in irc.callbacks
+                       if self.isPublic(cb)]
+            s = format(_('There is no command %q.'),
+                        callbacks.formatCommand(command))
+            if command[0].lower() in map(str.lower, plugins):
+                s += (' However, "{0}" is the name of a loaded plugin, and '
+                    'you may be able to find its provided commands '
+                    'using \'list {0}\'.'.format(command[0].title()))
+            irc.error(s)
+    help = wrap(help, [any('something')])
 
     @internationalizeDocstring
     def version(self, irc, msg, args):
