@@ -43,6 +43,8 @@ from supybot.i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization('Network')
 
 class Network(callbacks.Plugin):
+    """Provides network-related commands, such as connecting to multiple networks
+    and checking latency to the server."""
     _whois = {}
     _latency = {}
     def _getIrc(self, network):
@@ -62,6 +64,10 @@ class Network(callbacks.Plugin):
         provided, it will be sent to the server in a PASS command.  If --ssl is
         provided, an SSL connection will be attempted.
         """
+        if '.' in network:
+            irc.error("Network names cannot have a '.' in them. "
+            "Remember, this is the network name, not the actual "
+            "server you plan to connect to.", Raise=True)
         try:
             otherIrc = self._getIrc(network)
             irc.error(_('I\'m already connected to %s.') % network)
