@@ -79,6 +79,8 @@ registerDefaultPlugin('addcapability', 'Admin')
 registerDefaultPlugin('removecapability', 'Admin')
 
 class Owner(callbacks.Plugin):
+    """Owner-only commands for core Supybot. This is a core Supybot module
+    that should not be removed!"""
     # This plugin must be first; its priority must be lowest; otherwise odd
     # things will happen when adding callbacks.
     def __init__(self, irc=None):
@@ -446,6 +448,9 @@ class Owner(callbacks.Plugin):
         Unloads and subsequently reloads the plugin by name; use the 'list'
         command to see a list of the currently loaded plugins.
         """
+        if ircutils.strEqual(name, self.name()):
+            irc.error('You can\'t reload the %s plugin.' % name)
+            return
         callbacks = irc.removeCallback(name)
         if callbacks:
             module = sys.modules[callbacks[0].__module__]
