@@ -86,7 +86,7 @@ def process(f, *args, **kwargs):
     if resource and heap_size is None:
         heap_size = resource.RLIM_INFINITY
 
-    if conf.disableMultiprocessing:
+    if world.disableMultiprocessing:
         pn = kwargs.pop('pn', 'Unknown')
         cn = kwargs.pop('cn', 'unknown')
         try:
@@ -103,7 +103,7 @@ def process(f, *args, **kwargs):
                 '\tsudo rmdir /dev/shm\n'
                 '\tsudo ln -Tsf /{run,dev}/shm\n'
                 '(See https://github.com/travis-ci/travis-core/issues/187\n'
-                'for more informations about this bug.)\n')
+                'for more information about this bug.)\n')
         raise
     def newf(f, q, *args, **kwargs):
         if resource:
@@ -121,11 +121,14 @@ def process(f, *args, **kwargs):
     p.join(timeout)
     if p.is_alive():
         p.terminate()
+        q.close()
         raise ProcessTimeoutError("%s aborted due to timeout." % (p.name,))
     try:
         v = q.get(block=False)
     except Queue.Empty:
         return None
+    finally:
+        q.close()
     if isinstance(v, Exception):
         raise v
     else:
